<?php

/************************************************************************

FC2アフイリエイト・一般用用クラス

詳細は => https://affiliate.fc2.com/manual/manual_general_tracking.html

2014.04.11 新規作成 shima

************************************************************************/

/*

使用例)

require_once('Class_FC2Affiliate.php');

$sh_pass = "hogehoge";	//不正防止用ハッシュ用のパスワードをご利用の場合のみ

//送信データ作成
$arr = array (
			'shopid'		=> 'XXXXXXXXXXXXXXXX',	//ショップID
			'unique_id'		=> '12',				//ユニークID(80文字までの文字列)
			'amount'		=> 120,					//金額
			'uname'			=> "user1234",			//購入者ユーザー名
			'email'			=> "test@fctest.com",	//購入者e-mail
			'unit_num'		=> 1,					//商品個数。省略時は 0 にする。
);

echo Class_FC2Affiliate::send_data($arr, $sh_pass);


○emailを test@fc2.com にすると、
　「テスト用タグの実行結果」に記録されますが、
　実際の成果になりませんのでご注意下さい。



*/



define("AFFILIATE_SERVER_HOST",  "https://affiliate.fc2.com");
define("AFFILIATE_SERVER_PATH",  "/tracking/general_tracking.php");

class Class_FC2Affiliate
{
	function __construct()
	{
		
	}
	
	public static function send_data($param, $sh_pass="" )
	{
		$error = false;
		$arr_data = array();
		
		//値のチェック
		
		if( !$param['shopid'] || $param['shopid'] == "" )
		{
			echo("ERROR !! : 'shopid' is required.<br>\n");
			$error = true;
		}
		
		if( $param['amount']== "" || ($param['amount'] != "" && !is_numeric($param['amount'])) )
		{
			$param['amount'] = "0";
		}
		
		if(isset($param['uname']) && !preg_match('/^[a-z0-9,-_]{0,32}$/i',$param['uname']))
		{
			//英数字32文字以内
			echo("ERROR !! : invalid 'uname' value.<br>\n");
			$error = true;
		}
		
		if( isset($param['unit_num']) && !is_numeric($param['unit_num']) && $param['unit_num']!="" )
		{
			echo("ERROR !! : 'unit_num' must be integer.<br>\n");
			$error = true;
		}
		
		if( isset($param['ts']) ){
			if(!preg_match('/^[0-9]{14}$/',$param['ts']) )
			{
				echo("ERROR !! : invalid 'ts' value.<br>\n");
				$error = true;
			}
		}else{
			$param['ts'] = date('YmdHis');
		}
		
		if($error) return '';
		
		$arr_data = $param;
		
		if($sh_pass != "")
		{
			$sh = Class_FC2Affiliate::get_secure_hash($arr_data,$sh_pass);
			
			if( $sh != '')
			{
				$arr_data['sh'] = $sh;
			}
		}
		
		
		$imgtag = Class_FC2Affiliate::make_tag($arr_data);
		
		return $imgtag;
	}
	
	
	//不正防止用ハッシュ値を計算
	public static function get_secure_hash($arr_data,$sh_pass)
	{
		$required = array('shopid','unique_id','uname','email','amount','ts','unit_num');
		
		foreach( $required as $key => $param )
		{
			if( !array_key_exists( $param, $arr_data) )
			{
				$arr_data[$key] = "";
			}
		}
		
		$str = $sh_pass
				.$arr_data['shopid']
				.$arr_data['unique_id']
				.$arr_data['uname']
				.$arr_data['email']
				.$arr_data['amount']
				.$arr_data['ts']
				.$arr_data['unit_num'];
		
		return sha1($str);
	}
	
	//タグ用文字列作成
	public static function make_tag($arr_data)
	{
		foreach($arr_data as $key=>$value)
		{
			$arr_data[$key]=urlencode($value);
		}
		
		$sh = isset($arr_data['sh']) ? '&sh=' . $arr_data['sh'] : '' ;
		
		$tag = '<img src="'.AFFILIATE_SERVER_HOST.AFFILIATE_SERVER_PATH
				."?shopid={$arr_data['shopid']}"
				."&uname={$arr_data['uname']}"
				."&email={$arr_data['email']}"
				."&amount={$arr_data['amount']}"
				."&unique_id={$arr_data['unique_id']}"
			    ."&ts={$arr_data['ts']}"
				."&unit_num={$arr_data['unit_num']}"
				.$sh
				.'" width="1" height="1">';
		
		return $tag;
	}
}

?>